@@ -27,11 +27,10 @@ def dingding(access_token, content):
     return "fail: %s" % data.text
 
 
-def falcon(metric, value, tag, ctype='GAUGE', step=60):
+def falcon(metric, value, tag, ctype='GAUGE', step=60, lo_host=socket.gethostname()):
     '''
     推送方式：falcon
     '''
-    lo_host = socket.gethostname()
     payload = []
     ts = int(time.time())
     falcon_url = 'http://127.0.0.1:1988/v1/push'
